.. servalcat documentation master file, created by
   sphinx-quickstart on Fri Apr 22 07:49:31 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Servalcat - refinement and map calculation
==========================================

Servalcat (for **S**\ tructur\ **e** **r**\ efinement and **val**\ idation for **c**\ rystallography and single p\ **a**\ r\ **t**\ icle analysis) is a software package for atomic model refinement and map calculation.

Source code repository: https://github.com/keitaroyam/servalcat

Installation
------------
Please see https://github.com/keitaroyam/servalcat/blob/main/README.md#installation

References
----------

| Cryo-EM SPA refinement:
| `Yamashita, K., Palmer, C. M., Burnley, T., Murshudov, G. N. (2021) "Cryo-EM single particle structure refinement and map calculation using Servalcat" Acta Cryst. D77, 1282-1291 <https://doi.org/10.1107/S2059798321009475>`_

| Refmacat and restraint generation using GEMMI:
| `Yamashita, K., Wojdyr, M., Long, F., Nicholls, R. A., Murshudov, G. N. (2023) "GEMMI and Servalcat restrain REFMAC5" Acta Cryst. D79, 368-373 <https://doi.org/10.1107/S2059798323002413>`_

Table of Contents
-----------------
.. toctree::
   :maxdepth: 2

   overview
   spa
   spa_examples/index
   xtal
   refmac_keywords
   source
   commands
